netapp_ontap.models.aggregate_block_storage_hybrid_cache API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.aggregate_block_storage_hybrid_cache`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class AggregateBlockStorageHybridCacheSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the AggregateBlockStorageHybridCache object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `disk_count GET`

    Number of disks used in the cache tier of the aggregate. Only provided when hybrid_cache.enabled is 'true'.

    Example: 6

  `enabled GET`

    Specifies whether the aggregate uses HDDs with SSDs as a cache.

  `raid_type GET`

    RAID type for SSD cache of the aggregate. Only provided when hybrid_cache.enabled is 'true'.

    Valid choices:

    - raid_dp
    - raid_tec
    - raid4
  `size GET`

    Total usable space in bytes of SSD cache. Only provided when hybrid_cache.enabled is 'true'.

    Example: 1612709888

  `used GET`

    Space used in bytes of SSD cache. Only provided when hybrid_cache.enabled is 'true'.

    Example: 26501122